@@ -71,6 +71,7 @@ class Client(Callbacks, SocketHandler):
             },
             "t": 112
         }
+        sleep(2)
         data = json.dumps(data)
         self.send(data)
 
@@ -95,6 +96,7 @@ class Client(Callbacks, SocketHandler):
             },
             "t": 108
         }
+        sleep(2)
         data = json.dumps(data)
         self.send(data)
 
@@ -109,6 +111,7 @@ class Client(Callbacks, SocketHandler):
                 },
             "t": 112
         }
+        sleep(2)
         data = json.dumps(data)
         self.send(data)
 
@@ -137,6 +140,7 @@ class Client(Callbacks, SocketHandler):
             },
             "t": 112
         }
+        sleep(2)
         data = json.dumps(data)
         self.send(data)
         data = {
@@ -167,6 +171,38 @@ class Client(Callbacks, SocketHandler):
         data = json.dumps(data)
         self.send(data)
 
+    def send_action(self, actions: list,comId:str ,chatId: str =None, blogId: str = None, quizId: str = None, lastAction: bool = False):
+        # Action List
+        # Browsing
+
+        if lastAction is True: t = 306
+        else: t = 304
+
+        data = {
+            "o": {
+                "actions": actions,
+                "target": f"ndc://x{comId}/",
+                "ndcId": int(comId),
+                "params": {"topicIds": [45841, 17254, 26542, 42031, 22542, 16371, 6059, 41542, 15852]},
+                "id": "273887"
+            },
+            "t": t
+        }
+        
+
+        if blogId is not None or quizId is not None:
+            data["o"]["target"] = f"ndc://x{comId}/blog/{blogId}"
+            if blogId is not None: data["o"]["params"]["blogType"] = 0
+            if quizId is not None: data["o"]["params"]["blogType"] = 6
+        if chatId is not None:
+            data["o"]["target"]=f"ndc://x{comId}/chat-thread/{chatId}"
+            data["o"]["params"]={"membershipStatus":1,"threadType":2}
+
+        print(data)
+        sleep(2)
+        return self.send(json.dumps(data))
+
+
     def login_sid(self, SID: str):
         """
         Login into an account with an SID
@@ -181,6 +217,9 @@ class Client(Callbacks, SocketHandler):
         self.account: objects.UserProfile = self.get_user_info(uId)
         self.profile: objects.UserProfile = self.get_user_info(uId)
         headers.sid = self.sid
+        self.web_headers = headers.Headers(sid=self.sid).web_headers
+        self.new_headers = headers.Headers(sid=self.sid).lost_headers
+        self.reg_headers=headers.Headers(sid=self.sid).reg_headers
         self.start()
         self.run_socket()
 
@@ -220,6 +259,9 @@ class Client(Callbacks, SocketHandler):
             self.account: objects.UserProfile = objects.UserProfile(self.json["account"]).UserProfile
             self.profile: objects.UserProfile = objects.UserProfile(self.json["userProfile"]).UserProfile
             headers.sid = self.sid
+            self.web_headers = headers.Headers(sid=self.sid).web_headers
+            self.new_headers = headers.Headers(sid=self.sid).lost_headers
+            self.reg_headers=headers.Headers(sid=self.sid).reg_headers
             self.start()
             return response.status_code
 
@@ -582,13 +624,13 @@ class Client(Callbacks, SocketHandler):
     	       	pass
     	       	return shown
 
-    def check(email : str):
+    def check(self,email : str):
       data=json.dumps({'email': email})
       req=requests.post("https://aminoapps.com/api/register-check",data=data,headers=self.reg_headers)
       if req.status_code != 200 : raise TypeError(req.text)
       return json.loads(req.text)
       
-    def check_code(email : str,code : str):
+    def check_code(self,email : str,code : str):
         data=json.dumps({
         'validationContext':{'data': {'code': code},
         'identity': email,
@@ -598,7 +640,7 @@ class Client(Callbacks, SocketHandler):
         if req.status_code != 200 : raise TypeError(req.text)
         return json.loads(req.text)
         
-    def register_check(email : str,password : str):
+    def register_check(self,email : str,password : str):
       data=json.dumps({
       'email': email,
       'phoneNumber': "",
@@ -609,7 +651,7 @@ class Client(Callbacks, SocketHandler):
       return json.loads(req.text)
     
     def register_g(self,email : str, password : str,nickname : str,code : str):
-        data=json.dumps({
+        data=({
         'email': email,
         'nickname': nickname,
         'phoneNumber': "",
@@ -626,10 +668,14 @@ class Client(Callbacks, SocketHandler):
                 'type' : 1,
                 '__response': {}
         }}}) ; 
-        req=requests.post("https://aminoapps.com/api/register",data=data,headers=self.reg_headers)
-        print(req.text)
-        if req.status_code != 200 : raise TypeError(req.text)
+        req=requests.post("https://aminoapps.com/api/register",json=data,headers=self.web_headers)
         #print(req.text)
+        try:
+            if req.json()["result"]['api:message'] != "OK":
+                print(req.text)
+        except:
+            print(req.text)
+        print("Account Created")
     
     def verify_code(self,email):
         #while True:
@@ -645,7 +691,8 @@ class Client(Callbacks, SocketHandler):
     	print('Verification Code Sent')
     	vcode=self.verify_code(email)
     	self.register_g(email = email,password = password,nickname = nickname,code = vcode)
-    	print("Account Created")       
+    	return email
+    	       
 
     def sub_clients(self, start: int = 0, size: int = 25):
         """
